summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/core.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/core.py b/src/core.py
index ddb63502..1f93324d 100644
--- a/src/core.py
+++ b/src/core.py
@@ -615,8 +615,8 @@ class Core(object):
conversation = self.get_tab_by_name(jid.bare, tabs.ConversationTab)
if not conversation:
if create:
- # We create the conversation with the bare Jid if nothing was found
- conversation = self.open_conversation_window(jid.bare, False)
+ # We create the conversation with the full Jid if nothing was found
+ conversation = self.open_conversation_window(jid.full, False)
else:
conversation = None
return conversation